@@ -1,11 +1,32 @@
 `BasicHTML` <-
-function(cmds=NULL, HTMLobjects, Captions, MenuLabels, Comments, file="tmp.html", title="", width=480, height=480, FRAMES=FALSE, JSCPATH = "jsc", LaunchPage = FALSE, APPEND = FALSE, verbose=0){
+function(cmds=NULL, HTMLobjects, Captions, MenuLabels, Comments, file="tmp.html", title="", width=480, height=480, FRAMES=FALSE, JSCPATH = "jsc", LaunchPage = FALSE, APPEND = FALSE,  href = NULL, verbose=0){
 	#BasicHTML(cmds = c("plot(rnorm(100));","plot(1:10);"), HTMLobjects = list("Fig1.png", "Fig2.png"), Captions=c("Gaussian noise","seq 1:10"))
 	#x <- cbind.data.frame(x1 = round(rnorm(10),3), x2 = round(runif(10),3));
 	#attr(x, "HEADER") <- "some random numbers";
 	#BasicHTML(HTMLobjects = list("Fig1.png", x, "Fig2.png"), Captions=c("Gaussian noise","Gaussian and uniform random numbers", "seq 1:10"), file = paste(Sys.getenv("HOME"), "/public_html/tmp/tmp.html",sep=""), JSCPATH = "../jsc")
 	
   require(R2HTML);
+  HTMLInsertGraph <- function (GraphFileName = "", Caption = "", GraphBorder = 1, 
+    Align = "center", WidthHTML = 500, HeightHTML = NULL, file = get(".HTML.file"), 
+    append = TRUE, href = NULL, ...) 
+   {
+     cat("\n", file = file, append = append, ...)
+    
+    cat(paste("<p align=", Align, ">",if (!is.null(href)) 
+            paste("<a href=\"", href, "\"> ", sep = "")
+        else "","<img src='", GraphFileName, 
+        "' border=", GraphBorder, if (!is.null(WidthHTML)) 
+            paste(" width=", WidthHTML, sep = "")
+        else "", if (!is.null(HeightHTML)) 
+            paste(" height=", HeightHTML, sep = "")
+        else "", ">", if (!is.null(href)) "</a>" else "", sep = "", collapse = ""), file = file, 
+        append = TRUE, sep = "")
+    if (Caption != "") 
+        cat(paste("<br><i class=caption>", Caption, "</i>"), 
+            file = file, append = TRUE, sep = "")
+    invisible(return(TRUE))
+   }
+
   #require(Cairo);
   graphIndex <- sapply(HTMLobjects,is.character);
   graphfiles <- unlist(HTMLobjects[graphIndex]);
@@ -50,7 +71,7 @@ function(cmds=NULL, HTMLobjects, Captions, MenuLabels, Comments, file="tmp.html"
 	    eval(parse(text=cmds[i]));
 	    dev.off()
 	  }
-	  HTMLInsertGraph(graphfile,Caption=Captions[i], Align="left",file=file,WidthHTML=width, HeightHTML=height);
+	  HTMLInsertGraph(graphfile,Caption=Captions[i], Align="left",file=file,WidthHTML=width, HeightHTML=height, href=href[i]);
 	} else if (is.data.frame(HTMLobjects[[i]]) | is.matrix(HTMLobjects[[i]])) {
 	  HEADER <- "";
 	  try(HEADER <- attr(HTMLobjects[[i]],"HEADER"));
